==> gromacs_3.3.3.orig.tar.gz: gromacs-3.3.3/src/tools/correl.h <==
/*
 * $Id: correl.h,v 1.3.2.5 2008/02/29 07:02:54 spoel Exp $
 * 
 *                This source code is part of
 * 
 *                 G   R   O   M   A   C   S
 * 
 *          GROningen MAchine for Chemical Simulations
 * 
 *                        VERSION 3.3.3
 * Written by David van der Spoel, Erik Lindahl, Berk Hess, and others.
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2008, The GROMACS development team,
 * check out http://www.gromacs.org for more information.

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * If you want to redistribute modifications, please consider that
 * scientific software is very special. Version control is crucial -
 * bugs must be traceable. We will be happy to consider code for
 * inclusion in the official distribution, but derived work must not
 * be called official GROMACS. Details are found in the README & COPYING
 * files - if they are missing, get the official version at www.gromacs.org.
 * 
 * To help us fund GROMACS development, we humbly ask that you cite
 * the papers on the package - you can find them in the top README file.
 * 
 * For more info, check our website at http://www.gromacs.org
 * 
 * And Hey:
 * Groningen Machine for Chemical Simulation
 */

#ifndef _correl_h
#define _correl_h

#include "typedefs.h"
#include "gmx_fft.h"


void 
correl(real data1[],real data2[],int n,real ans[]);

void 
four1(real data[],int nn,int isign);



typedef struct {
  int n;
  gmx_fft_t  fft_setup;
  real *buf1,*buf2,*abuf;
} correl_t;

extern correl_t *init_correl(int n);
extern void done_correl(correl_t *c);

#endif

==> gromacs_4.0.5.orig.tar.gz: gromacs-4.0.5/src/tools/correl.h <==
/*
 * $Id: correl.h,v 1.5.2.1 2008/10/07 22:49:41 lindahl Exp $
 * 
 *                This source code is part of
 * 
 *                 G   R   O   M   A   C   S
 * 
 *          GROningen MAchine for Chemical Simulations
 * 
 * Written by David van der Spoel, Erik Lindahl, Berk Hess, and others.
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2008, The GROMACS development team,
 * check out http://www.gromacs.org for more information.
 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * If you want to redistribute modifications, please consider that
 * scientific software is very special. Version control is crucial -
 * bugs must be traceable. We will be happy to consider code for
 * inclusion in the official distribution, but derived work must not
 * be called official GROMACS. Details are found in the README & COPYING
 * files - if they are missing, get the official version at www.gromacs.org.
 * 
 * To help us fund GROMACS development, we humbly ask that you cite
 * the papers on the package - you can find them in the top README file.
 * 
 * For more info, check our website at http://www.gromacs.org
 * 
 * And Hey:
 * Gallium Rubidium Oxygen Manganese Argon Carbon Silicon
 */

#ifndef _correl_h
#define _correl_h

#include "typedefs.h"
#include "gmx_fft.h"


typedef struct {
  int n;
  gmx_fft_t  fft_setup;
  real *buf1,*buf2,*abuf;
} correl_t;

extern correl_t *init_correl(int n);
extern void done_correl(correl_t *c);

extern void correl(real data1[],real data2[],int n,real ans[]);
extern void four1(real data[],int nn,int isign);

#endif
